class InsightServiceCfg:
    PROD_BASE_URL = "https://t608jbcx83.execute-api.ap-southeast-1.amazonaws.com/dev/api/v1"
    QA_BASE_URL = "https://rn0t0s00e2.execute-api.ap-southeast-1.amazonaws.com/qa/api/v1"
    X_API_KEY = "X-Api-Key"
    BATCH_SIZE = 300
    MAX_SIZE = 5000


